# -*- encoding: utf-8 -*-

from django.contrib import admin
from django import forms
from django.contrib.auth.models import User, Group

class GroupUsersForm(forms.ModelForm):
    LABEL = u'Utilisateurs associés'
    users = forms.ModelMultipleChoiceField(
        queryset=User.objects.filter(is_active=True, is_staff=True).order_by('username'), 
        label=LABEL, 
        widget=admin.widgets.FilteredSelectMultiple(LABEL, False),
        required=False,
        )
    
    class Meta:
        model = Group
        fields = ('name', 'permissions',)

    def __init__(self, *args, **kwargs):
        super(GroupUsersForm, self).__init__(*args, **kwargs)

        # cas édition, on prépopule les users déjà membre
        if kwargs.has_key('instance'):
            instance = kwargs['instance']
            user_ids = [u.id for u in instance.user_set.all().order_by('username')]
            self.fields['users'].initial = user_ids

    def save(self, commit=True):
        # on s'assure que le groupe existe avant d'associer les personnes
        instance = super(GroupUsersForm, self).save(commit)
        instance.save()
        users_selected = self.cleaned_data['users']
        instance.user_set = users_selected
        return instance


